Crate sac13

SAC13 is a 13-month solar calendar with fixed four-week months, starting each year with the March Equinox. This library is the Rust reference implementation for SAC13.

You can find details about SAC13 here: https://sac13.net/

This library provides the data types and functions to convert from the Gregorian Calendar to SAC13 and vice versa. It also provides conversions from and to Julian Day Numbers if you want to interop with other calendar systems.

Modules

day_counts
Primitive types for linear day counts like the Julian Day Number.
prelude
Reexports for common types.

Macros

date
Creates a SAC13 date with a statically known and compile time checked value.
date_greg
Creates a Gregorian Calendar date with a statically known and compile time checked value.
year
Creates a SAC13 year with a statically and compile time checked value.

Structs

Date
SAC13 date.
GregorianDate
Gregorian Calendar date (proleptic).
ParsedDate
Year
SAC13 year. It roughly corresponds to the Gregorian Year + 10’000. Roughly, because the Gregorian Calendar starts its year with January and SAC13 with March.

Enums

ComponentOrder
GregorianOrSac13
Month
Represents a month on the SAC13 calendar.
YearType
The type of the year.

Traits

CalendarDate
A minimum set of functionality a typical calendar should provide.

Functions

parse_date_str
Parses various SAC13 and Gregorian Calendar formats.